[![pypi](https://img.shields.io/pypi/v/abstra.svg)](https://pypi.python.org/pypi/abstra)
[![PyPI Downloads](https://img.shields.io/pypi/dm/abstra.svg)](https://pypi.org/project/abstra/)
[![Code check](https://github.com/abstra-app/abstra-lib/actions/workflows/code_check.yml/badge.svg)](https://github.com/abstra-app/abstra-lib/actions/workflows/code_check.yml)

# Abstra Python Package

Drag'n drop app builder for Python.

## Install

This package is compatible with Python >= 3.7

```
pip install abstra --upgrade
```

## Usage

Run the CLI server from any directory to edit your app

```
abstra serve ./your-app-directory
```

Deploy with a single command

```
abstra deploy ./your-app-directory
```

[Site](https://abstra.io) | [Docs](https://docs.abstra.io) | [Cloud](https://cloud.abstra.io) | [Privacy](./PRIVACY.md)